@@ -2,7 +2,7 @@
 import ast
 import re
 import warnings
-from typing import List, Tuple, Type, Union, Callable
+from typing import Any, List, Union, Tuple, Type, Callable, overload
 
 from executing import Source
 
@@ -216,9 +216,26 @@ def will(frame: int = 1, raise_exc: bool = True) -> str:
     return node.attr
 
 
+@overload
+def nameof(var: Any, *, frame: int = 1, vars_only: bool = True) -> str:
+    ...
+
+
+@overload
 def nameof(
-    var,
-    *more_vars,
+    var: Any,
+    more_var: Any,
+    /,  # introduced in python 3.8
+    *more_vars: Any,
+    frame: int = 1,
+    vars_only: bool = True,
+) -> Tuple[str, ...]:
+    ...
+
+
+def nameof(
+    var: Any,
+    *more_vars: Any,
     frame: int = 1,
     vars_only: bool = True,
 ) -> Union[str, Tuple[str, ...]]:
@@ -317,6 +334,34 @@ def nameof(
     return out if more_vars else out[0]  # type: ignore
 
 
+@overload
+def argname(
+    arg: str,
+    *,
+    func: Callable = None,
+    dispatch: Type = None,
+    frame: int = 1,
+    ignore: IgnoreType = None,
+    vars_only: bool = True,
+) -> ArgSourceType:
+    ...
+
+
+@overload
+def argname(
+    arg: str,
+    more_arg: str,
+    /,  # introduced in python 3.8
+    *more_args: str,
+    func: Callable = None,
+    dispatch: Type = None,
+    frame: int = 1,
+    ignore: IgnoreType = None,
+    vars_only: bool = True,
+) -> Tuple[ArgSourceType, ...]:
+    ...
+
+
 def argname(
     arg: str,
     *more_args: str,
@@ -325,7 +370,7 @@ def argname(
     frame: int = 1,
     ignore: IgnoreType = None,
     vars_only: bool = True,
-) -> ArgSourceType:
+) -> Union[ArgSourceType, Tuple[ArgSourceType, ...]]:
     """Get the names/sources of arguments passed to a function.
 
     Instead of passing the argument variables themselves to this function
@@ -426,7 +471,7 @@ def argname(
             "Have you specified the right `frame` or `func`?"
         ) from err
 
-    out = []  # type: List[ArgSourceType]
+    out: List[ArgSourceType] = []
     farg_star = False
     for farg in (arg, *more_args):
 
