@@ -18,7 +18,7 @@ from os import path
 from pathlib import Path
 from functools import lru_cache, singledispatch
 from types import ModuleType, FunctionType, CodeType, FrameType
-from typing import Tuple, Union, List, Mapping, Callable
+from typing import Tuple, Union, List, Mapping, Callable, Dict
 
 from executing import Source
 
@@ -212,28 +212,49 @@ def bytecode_nameof(code: CodeType, offset: int) -> str:
     python shell, with `eval`, or other circumstances where the code is
     manipulated to run but sourcecode is not available.
     """
-    instructions = list(dis.get_instructions(code))
+    kwargs: Dict[str, bool] = (
+        {"show_caches": True} if sys.version_info[:2] >= (3, 11) else {}
+    )
+
+    instructions = list(dis.get_instructions(code, **kwargs))
     ((current_instruction_index, current_instruction),) = (
         (index, instruction)
         for index, instruction in enumerate(instructions)
         if instruction.offset == offset
     )
 
-    if current_instruction.opname in ("CALL_FUNCTION_EX", "CALL_FUNCTION_KW"):
-        raise VarnameRetrievingError(
-            "'nameof' can only be called with a single positional argument "
-            "when source code is not avaiable."
-        )
+    while current_instruction.opname == "CACHE":  # pragma: no cover
+        current_instruction_index -= 1
+        current_instruction = instructions[current_instruction_index]
 
-    if current_instruction.opname not in ("CALL_FUNCTION", "CALL_METHOD"):
+    pos_only_error = VarnameRetrievingError(
+        "'nameof' can only be called with a single positional argument "
+        "when source code is not avaiable."
+    )
+    if current_instruction.opname in (  # pragma: no cover
+        "CALL_FUNCTION_EX",
+        "CALL_FUNCTION_KW",
+    ):
+        raise pos_only_error
+
+    if current_instruction.opname not in (
+        "CALL_FUNCTION",
+        "CALL_METHOD",
+        "CALL",
+    ):
         raise VarnameRetrievingError("Did you call 'nameof' in a weird way?")
 
-    name_instruction = instructions[current_instruction_index - 1]
+    current_instruction_index -= 1
+    name_instruction = instructions[current_instruction_index]
+    while name_instruction.opname in ("CACHE", "PRECALL"):  # pragma: no cover
+        current_instruction_index -= 1
+        name_instruction = instructions[current_instruction_index]
+
+    if name_instruction.opname == "KW_NAMES":  # pragma: no cover
+        raise pos_only_error
 
     if not name_instruction.opname.startswith("LOAD_"):
-        raise VarnameRetrievingError(
-            "Argument must be a variable or attribute"
-        )
+        raise VarnameRetrievingError("Argument must be a variable or attribute")
 
     name = name_instruction.argrepr
     if not name.isidentifier():
